/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.function.library.cdt;

import java.util.List;

import org.apache.jena.cdt.CDTValue;
import org.apache.jena.sparql.expr.ExprEvalException;
import org.apache.jena.sparql.expr.NodeValue;

public class HeadFct extends FunctionBase1List
{
    @Override
    protected NodeValue _exec( final List<CDTValue> list, final NodeValue nvList ) {
        if ( list.size() == 0 )
            throw new ExprEvalException("Empty list");

        final CDTValue value = list.get(0);
        if ( value.isNull() ) {
            throw new ExprEvalException("accessing null value from list" );
        }
        else if ( value.isNode() ) {
            return NodeValue.makeNode( value.asNode() );
        }
        else {
            throw new ExprEvalException("Unexpected type of CDTValue: " + value.getClass().getName() );
        }
    }

}
