/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.tdb1.sys;

import java.util.Iterator ;
import java.util.concurrent.atomic.AtomicLong ;

import org.apache.jena.tdb1.TDB1Exception;

/** A policy that provide read-only access */ 
public class DatasetControlReadOnly implements DatasetControl
{
    private final AtomicLong readCounter = new AtomicLong(0) ;
    
    public DatasetControlReadOnly()
    { }

    @Override
    public void startRead()
    {
        readCounter.getAndIncrement() ;
    }

    @Override
    public void finishRead()
    {
        readCounter.decrementAndGet() ;
    }

    @Override
    public void startUpdate()
    {
        throw new TDB1Exception("Read-only") ;
    }

    @Override
    public void finishUpdate()
    {
        throw new TDB1Exception("Read-only") ;
    }

    @Override
    public <T> Iterator<T> iteratorControl(Iterator<T> iter) { return iter ; }
}
